@@ -160,6 +160,7 @@ class Bootstrap:
         #     console.print(f"Registrar {config['registrar']} not available.")
         #     return 1
 
+        secret = web.nbrandom(4)
         machines = config.get("machines", {})
         versions = web.host.Machine.versions
         start_time = time.time()
@@ -201,12 +202,12 @@ class Bootstrap:
             console.print("Installing nginx")
             machine.setup_nginx()
             console.print(f"Installing application: {self.app} of {self.package}")
-            machine.setup_app(self.package, self.app, config["host_token"])
+            machine.setup_app(self.package, self.app, config["host_token"], secret)
             time.sleep(2)
         console.rule(
             f"[green]Bootstrapped {self.package} ({self.app}) at {machine.address}"
         )
-        webbrowser.open(f"https://{machine.address}")
+        webbrowser.open(f"https://{machine.address}?secret={secret}")
         machines[self.website] = machine.address
         update_config(machines=machines)
         return 0
