@@ -857,7 +857,7 @@ class Application:
         self.server = gevent.spawn(server.serve_forever)
         self.server.spawn()  # TODO start()?
 
-    def reload_config(self, path=None):
+    def reload_config(self, path="webcfg.ini"):
         self.cfg = {}
         path = os.getenv("WEBCFG", path)
         try:
@@ -867,8 +867,8 @@ class Application:
             pass
         return path
 
-    def update_config(self, key, value, path=None):
-        path = self.reload_config(path)
+    def update_config(self, key, value):
+        path = self.reload_config()
         self.cfg[key] = value
         with pathlib.Path(path).open("w") as fp:
             toml.dump(self.cfg, fp)
